\name{convert}
\alias{convert}

\title{Converts CEL Files}
\description{Converts CEL files, using the necessary CDF file, to
  a table with relevant probe pair information.}
}
\usage{
convert.affy(file,path=paste(.path.package(package="affy"),"/exec/",sep=""),
             read=T, chip.names=NULL, verbose=T)
}
\arguments{
  \item{file}{a character string naming the file to write the table to.}
  \item{path}{character string containing the path where
    \code{\link{cel2tab.pl}} is located. See details below.}
  \item{read}{logical value. If \code{TRUE} the function
    \code{\link{read.affy}} is invoked and a
    \code{\link{probe.level.object}} is returned.} 
  \item{chip.names}{a character vector containing the names to be
    used for the different chips. If \code{read=F} this is ignored.}
}
\details{
  This function invokes the perl script \code{\link{cel2tab.pl}}.
  The script should be executable and perl properly installed.

  All the \code{CEL} files and respective \code{CDF} file should be in the
  working directory. The perl script will use all files ending in
  \code{.CEL} or \code{.cel}. For the script to recognize the \code{CDF} file
  it needs to end in \code{.CDF} or \code{.cdf}. Make sure there is only
  one \code{CDF} in your working directory.

  \code{file} will contain only numeric data. A numeric ID is given to
  each probe set and the name is stored in a separate file. The probe
  set names will be stored in a file with the same name as the
  \code{CDF} file with suffux \code{.info}. 

  An alternative to using
  \code{convert} is to convert the \code{CEL} files first (before invoking R) using the script and
  then reading in the data using \code{\link{read.affy}}.

  If \code{chip.names} is \code{NULL} then \code{read.affy} uses the
  names of the \code{CEL} files with the suffix .CEL removed.
}
\value{If \code{read=T} this function returns NULL. Otherwise it returns
  a \code{\link{probe.level.object}}.
}

\references{ Affymetrix (1999) Gene Chip Analysis Suite User Guide
  (Affymetrix, Santa Clara)}
\author{Rafael A. Irizarry}
%\note{ ~~further notes~~ }
\seealso{ \code{\link{read.affy}}, \code{\link{probe.level.object}},
  \code{\link{cel2tab.pl}}}
\keyword{file}
\keyword{utilities}
%\examples{
%#---- Should be DIRECTLY executable !! ----
%#-- ==>  Define data, use random,
%#--	     or do  help(data=index)  for the standard data sets.
